==> nextcloud-25.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/sv.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Integritet",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Sekretesscentret visar var din data lagras och vem som kan komma åt den, antingen för att du delade med dem eller för att de är administratörer.",
    "Remove external {propertyName} admin" : "Ta bort extern {propertyName} admin",
    "Add external admin" : "Lägg till extern administratör",
    "Name of external admin" : "Namn på extern administratör",
    "Adapt encryption" : "Anpassa kryptering",
    "This server is using full-disk-encryption." : "Servern använder fullständig disk-kryptering.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Dina filer på externa lagringsutrymmen kan krypteras med {linkopen}serverkryptering ↗{linkclose} med en huvudnyckel baserad på deras konfiguration.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Dina filer på externa lagringsutrymmen kan krypteras med {linkopen}serverkryptering ↗{linkclose} med en individuell nyckel baserad på deras konfiguration.",
    "Additionally, this server is protected with full-disk-encryption." : "Dessutom är servern skyddad med fullständig diskkryptering.",
    "This server is protected with full-disk-encryption." : "Servern är skyddad med fullständig disk-kryptering.",
    "Your files are not protected by encryption." : "Dina filer är inte skyddade med kryptering.",
    "Your data is located in:" : "Din data finns i:",
    "The admin has not selected the location of the server yet." : "Administratören har inte valt någon plats för servern än.",
    "Change data location" : "Ändra lagringsplats för data",
    "Please select a region" : "Välj en region",
    "You don't have any shares with individual users." : "Du har inga delningar med enskilda användare.",
    "Somaliland" : "Somaliland",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "United Arab Emirates",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua och Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanien",
    "Armenia" : "Armenien",
    "Angola" : "Angola",
    "Antarctica" : "Antarktis",
    "Argentina" : "Argentina",
    "American Samoa" : "Amerikanska Samoa",
    "Austria" : "Österrike",
    "Australia" : "Australien",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland",
    "Azerbaijan" : "Azerbajdzjan",
    "Bosnia and Herzegovina" : "Bosnien och Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgien",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarien",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius and Saba",
    "Brazil" : "Brasilien",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvet Island",
    "Botswana" : "Botswana",
    "Belarus" : "Vitryssland",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Cocos (Keeling) Islands",
    "Democratic Republic of the Congo" : "Kongo-Kinshasa",
    "Central African Republic" : "Central African Republic",
    "Congo" : "Congo",
    "Switzerland" : "Schweiz",
    "Cote d'Ivoire" : "Elfenbenskusten",
    "Cook Islands" : "Cook Islands",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Kina",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kap Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Julön",
    "Cyprus" : "Cypern",
    "Czech" : "Czech",
    "Germany" : "Tyskland",
    "Djibouti" : "Djibouti",
    "Denmark" : "Danmark",
    "Dominican Republic" : "Dominikanska republiken",
    "Algeria" : "Algeriet",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estland",
    "Egypt" : "Egypten",
    "West Sahara" : "Västsahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanien",
    "Ethiopia" : "Etiopien",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Falklandsöarna",
    "Micronesia" : "Mikronesien",
    "Faroe Islands" : "Färöarna",
    "France" : "Frankrike",
    "Gabon" : "Gabon",
    "United Kingdom" : "Storbritannien",
    "Grenada" : "Grenada",
    "Georgia" : "Georgien",
    "French Guiana" : "Franska Guyana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grönland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Equatorial Guinea",
    "Greece" : "Grekland",
    "South Georgia and the South Sandwich Islands" : "South Georgia and the South Sandwich Islands",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard Island och McDonald Islands",
    "Croatia" : "Kroatien",
    "Haiti" : "Haiti",
    "Hungary" : "Ungern",
    "Indonesia" : "Indonesien",
    "Ireland" : "Irland",
    "Israel" : "Israel",
    "Isle of Man" : "Isle of Man",
    "India" : "Indien",
    "British Indian Ocean Territory" : "British Indian Ocean Territory",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Island",
    "Italy" : "Italien",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordanien",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirgizistan",
    "Cambodia" : "Kambodja",
    "Kiribati" : "Kiribati",
    "Comores" : "Comores",
    "Saint Kitts and Nevis" : "Saint Kitts and Nevis",
    "North Korea" : "Nordkorea",
    "South Korea" : "Sydkorea",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Cayman Islands",
    "Kazakhstan" : "Kazakstan",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litauen",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Lettland",
    "Libya" : "Libyen",
    "Morocco" : "Marocko",
    "Monaco" : "Monaco",
    "Moldova" : "Moldavien",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "Saint Martin",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshall Islands",
    "Macedonia" : "Makedonien",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongoliet",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Northern Mariana Islands",
    "Mauritania" : "Mauretanien",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldiverna",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nya Kaledonien",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolk Island",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Nederländerna",
    "Norway" : "Norge",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nya Zeeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Franska Polynesien",
    "Papua New Guinea" : "Papua Nya Guinea",
    "Philippines" : "Filippinerna",
    "Pakistan" : "Pakistan",
    "Poland" : "Polen",
    "Saint Pierre and Miquelon" : "Saint Pierre and Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine" : "Palestina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Rumänien",
    "Serbia" : "Serbien",
    "Russia" : "Ryssland",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudi Arabia",
    "Solomon Islands" : "Salomonöarna",
    "Seychelles" : "Seychellerna",
    "Sudan" : "Sudan",
    "Sweden" : "Sverige",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension and Tristan da Cunha",
    "Slovenia" : "Slovenien",
    "Svalbard and Jan Mayen" : "Svalbard and Jan Mayen",
    "Slovakia" : "Slovakien",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "South Sudan",
    "Sao Tome and Principe" : "Sao Tome and Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "Syrien",
    "Swaziland" : "Swaziland",
    "Turks and Caicos Islands" : "Turks- och Caicosöarna",
    "Chad" : "Chad",
    "Fr. S. Antarctic Lands" : "Franska sydterritorierna",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tadzjikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisien",
    "Tonga" : "Tonga",
    "Turkey" : "Turkiet",
    "Trinidad and Tobago" : "Trinidad och Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "United States Minor Outlying Islands",
    "United States" : "USA",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Holy See",
    "Saint Vincent and the Grenadines" : "Saint Vincent and the Grenadines",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Virgin Islands (British)",
    "Virgin Islands (U.S.)" : "Virgin Islands (U.S.)",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis and Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sydafrika",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your %s account" : "Ditt %s konto",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Din data representerar vem du är och kan lätt missbrukas. Vi på Nextcloud anser att du har rätt att bestämma vad som händer med din data. Nextcloud skyddar dina rättigheter enligt definitionen i användardata-manifestet!",
    "User Data Manifesto 2.0" : "Användardata-manifest 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definiera grundläggande rättigheter för människor att kontrollera sina egna data i internetåldern",
    "Control" : "Kontroll",
    "over user data access" : "över användardataåtkomst",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Data som uttryckligen laddas upp av en användare bör vara under kontroll av den användaren. Användare ska kunna bestämma vem som har direkt åtkomst till deras data och med vilka rättigheter och licenser sådan åtkomst beviljas.",
    "Knowledge" : "Kunskap",
    "of how the data is stored" : "om hur data lagras",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "När data laddas upp till en viss tjänsteleverantör bör användarna informeras om var den specifika tjänsteleverantören lagrar data, hur länge, i vilken jurisdiktion den specifika tjänsteleverantören är verksam och vilka lagar som gäller.",
    "Freedom" : "Frihet",
    "to choose a platform" : "att välja en plattorm",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Användare bör alltid kunna hämta ut sina data från tjänsten när som helst utan att uppleva någon leverantörsinlåsning. Öppna standarder för format och protokoll är nödvändiga för att kunna garantera detta.",
    "Learn more ↗" : "Läs mer ↗",
    "Where is your data?" : "Var är din data?",
    "Who has access to your data?" : "Vem har åtkomst till din data?",
    "Administrators" : "Administratörer",
    "People you shared with" : "Personer du delat med",
    "Privacy policy" : "Integritetspolicy",
    "Read the privacy policy." : "Läs integritetspolicy.",
    "Encryption" : "Kryptering",
    "Remove external admin" : "Ta bort extern administratör",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key." : "Din hemkatalog är krypterad med {linkopen}serverkryptering ↗{linkclose} med en huvudnyckel.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key." : "Din hemkatalog är krypterad med {linkopen}serverkryptering ↗{linkclose} med en individuell nyckel per användare."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/sv.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Integritet",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Sekretesscentret visar var din data lagras och vem som kan komma åt den, antingen för att du delade med dem eller för att de är administratörer.",
    "Error loading additional administrator." : "Kunde inte läsa in ytterligare administratör.",
    "Error adding new administrator." : "Kunde inte lägga till ny administratör.",
    "Error deleting new administrator." : "Kunde inte ta bort ny administratör.",
    "Administrators" : "Administratörer",
    "The following accounts are designated administrators and may potentially have access to your data through system storage or backups. However, they do not have easy access to your data via the web interface or client applications." : "Följande konton är utsedda administratörer och kan potentiellt ha tillgång till din data genom systemlagring eller säkerhetskopior. De har dock inte lätt tillgång till din data via webbgränssnitt eller klientapplikationer.",
    "Loading administrators …" : "Läser in administratörer …",
    "Remove external {propertyName} admin" : "Ta bort extern {propertyName} admin",
    "Add external admin" : "Lägg till extern administratör",
    "Cancel" : "Avbryt",
    "Add" : "Lägg till",
    "Name of external admin" : "Namn på extern administratör",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "Dina filer krypteras med {linkopen}serverkryptering ↗{linkclose} med en huvudnyckel. Det betyder att administratörer kan komma åt dina filer, men inte läsa deras innehåll.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Dina filer på externa lagringsutrymmen kan krypteras med {linkopen}serverkryptering ↗{linkclose} med en huvudnyckel baserad på deras konfiguration.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "Dina filer krypteras med {linkopen}serverkryptering ↗{linkclose} som använder individuell användarnyckel. Det betyder att administratörer kan komma åt dina filer, men inte läsa deras innehåll.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Dina filer på externa lagringsutrymmen kan krypteras med {linkopen}serverkryptering ↗{linkclose} med en individuell nyckel baserad på deras konfiguration.",
    "Additionally, this server is protected with full-disk-encryption." : "Dessutom är servern skyddad med fullständig diskkryptering.",
    "This server is protected with full-disk-encryption." : "Servern är skyddad med fullständig disk-kryptering.",
    "Your files are not protected by encryption." : "Dina filer är inte skyddade med kryptering.",
    "Error saving new state of full-disk-encryption" : "Fel vid sparande av nytt tillstånd för fullständig diskkryptering",
    "Encryption" : "Kryptering",
    "Edit encryption" : "Redigera kryptering",
    "Edit" : "Redigera",
    "This server is using full-disk-encryption." : "Servern använder fullständig disk-kryptering.",
    "Privacy policy" : "Integritetspolicy",
    "Read the privacy policy ↗" : "Läs integritetspolicyn ↗",
    "Error loading information about shares." : "Fel vid inläsning av information om delningar.",
    "People you've shared with" : "Personer du har delat med",
    "Loading people you've shared with …" : "Laddar personer du har delat med …",
    "You do not have any shares with individual users." : "Du har inga delningar med enskilda användare.",
    "Who has access to your data?" : "Vem har åtkomst till din data?",
    "Error saving new location of the server" : "Kunde inte spara serverns nya plats",
    "Where is your data?" : "Var är din data?",
    "Your data is located in:" : "Din data finns i:",
    "An admin has not selected the location of the server yet." : "En administratör har ännu inte valt en plats för servern.",
    "Change data location" : "Ändra lagringsplats för data",
    "Region" : "Län",
    "Please select a region" : "Välj en region",
    "User Data Manifesto 2.0" : "Användardata-manifest 2.0",
    "Defining basic rights for people to control their own data in the internet age." : "Definiera grundläggande rättigheter för människor att kontrollera sina egna data i internetåldern.",
    "Control" : "Kontroll",
    "over user data access" : "över användardataåtkomst",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Data som uttryckligen laddas upp av en användare bör vara under kontroll av den användaren. Användare ska kunna bestämma vem som har direkt åtkomst till deras data och med vilka rättigheter och licenser sådan åtkomst beviljas.",
    "Knowledge" : "Kunskap",
    "of how the data is stored" : "om hur data lagras",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "När data laddas upp till en viss tjänsteleverantör bör användarna informeras om var den specifika tjänsteleverantören lagrar data, hur länge, i vilken jurisdiktion den specifika tjänsteleverantören är verksam och vilka lagar som gäller.",
    "Freedom" : "Frihet",
    "to choose a platform" : "att välja en plattorm",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Användare bör alltid kunna hämta ut sina data från tjänsten när som helst utan att uppleva någon leverantörsinlåsning. Öppna standarder för format och protokoll är nödvändiga för att kunna garantera detta.",
    "Learn more ↗" : "Läs mer ↗",
    "Your {serverName} account" : "Ditt {serverName} konto",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Din data representerar vem du är och kan lätt missbrukas. Vi på Nextcloud anser att du har rätt att bestämma vad som händer med din data. Nextcloud skyddar dina rättigheter enligt definitionen i användardata-manifestet!",
    "Somaliland" : "Somaliland",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "United Arab Emirates",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua och Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanien",
    "Armenia" : "Armenien",
    "Angola" : "Angola",
    "Antarctica" : "Antarktis",
    "Argentina" : "Argentina",
    "American Samoa" : "Amerikanska Samoa",
    "Austria" : "Österrike",
    "Australia" : "Australien",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland",
    "Azerbaijan" : "Azerbajdzjan",
    "Bosnia and Herzegovina" : "Bosnien och Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgien",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarien",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius and Saba",
    "Brazil" : "Brasilien",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvet Island",
    "Botswana" : "Botswana",
    "Belarus" : "Vitryssland",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Cocos (Keeling) Islands",
    "Democratic Republic of the Congo" : "Kongo-Kinshasa",
    "Central African Republic" : "Central African Republic",
    "Congo" : "Congo",
    "Switzerland" : "Schweiz",
    "Cote d'Ivoire" : "Elfenbenskusten",
    "Cook Islands" : "Cook Islands",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Kina",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kap Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Julön",
    "Cyprus" : "Cypern",
    "Czech" : "Tjeckien",
    "Germany" : "Tyskland",
    "Djibouti" : "Djibouti",
    "Denmark" : "Danmark",
    "Dominican Republic" : "Dominikanska republiken",
    "Algeria" : "Algeriet",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estland",
    "Egypt" : "Egypten",
    "West Sahara" : "Västsahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanien",
    "Ethiopia" : "Etiopien",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Falklandsöarna",
    "Micronesia" : "Mikronesien",
    "Faroe Islands" : "Färöarna",
    "France" : "Frankrike",
    "Gabon" : "Gabon",
    "United Kingdom" : "Storbritannien",
    "Grenada" : "Grenada",
    "Georgia" : "Georgien",
    "French Guiana" : "Franska Guyana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grönland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Equatorial Guinea",
    "Greece" : "Grekland",
    "South Georgia and the South Sandwich Islands" : "Sydgeorgien och Sydsandwichöarna",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard- och McDonaldöarna",
    "Honduras" : "Honduras",
    "Croatia" : "Kroatien",
    "Haiti" : "Haiti",
    "Hungary" : "Ungern",
    "Indonesia" : "Indonesien",
    "Ireland" : "Irland",
    "Israel" : "Israel",
    "Isle of Man" : "Isle of Man",
    "India" : "Indien",
    "British Indian Ocean Territory" : "Brittiska territoriet i Indiska oceanen",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Island",
    "Italy" : "Italien",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordanien",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirgizistan",
    "Cambodia" : "Kambodja",
    "Kiribati" : "Kiribati",
    "Comores" : "Komorerna",
    "Saint Kitts and Nevis" : "Saint Kitts och Nevis",
    "North Korea" : "Nordkorea",
    "South Korea" : "Sydkorea",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Caymanöarna",
    "Kazakhstan" : "Kazakstan",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litauen",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Lettland",
    "Libya" : "Libyen",
    "Morocco" : "Marocko",
    "Monaco" : "Monaco",
    "Moldova" : "Moldavien",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "Saint Martin",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshallöarna",
    "Macedonia" : "Makedonien",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongoliet",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Nordmarianerna",
    "Mauritania" : "Mauretanien",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldiverna",
    "Malawi" : "Malawi",
    "Mexico" : "Mexiko",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Moçambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nya Kaledonien",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolkön",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Nederländerna",
    "Norway" : "Norge",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nya Zeeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Franska Polynesien",
    "Papua New Guinea" : "Papua Nya Guinea",
    "Philippines" : "Filippinerna",
    "Pakistan" : "Pakistan",
    "Poland" : "Polen",
    "Saint Pierre and Miquelon" : "Saint-Pierre och Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine" : "Palestina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Rumänien",
    "Serbia" : "Serbien",
    "Russia" : "Ryssland",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudiarabien",
    "Solomon Islands" : "Salomonöarna",
    "Seychelles" : "Seychellerna",
    "Sudan" : "Sudan",
    "Sweden" : "Sverige",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sankta Helena, Ascension och Tristan da Cunha",
    "Slovenia" : "Slovenien",
    "Svalbard and Jan Mayen" : "Svalbard och Jan Mayen",
    "Slovakia" : "Slovakien",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sydsudan",
    "Sao Tome and Principe" : "São Tomé och Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "Syrien",
    "Swaziland" : "Swaziland",
    "Turks and Caicos Islands" : "Turks- och Caicosöarna",
    "Chad" : "Tchad",
    "Fr. S. Antarctic Lands" : "Franska sydterritorierna",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tadzjikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisien",
    "Tonga" : "Tonga",
    "Turkey" : "Turkiet",
    "Trinidad and Tobago" : "Trinidad och Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Förenta staternas mindre öar i Oceanien och Västindien",
    "United States" : "USA",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Heliga stolen",
    "Saint Vincent and the Grenadines" : "Saint Vincent och Grenadinerna",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Brittiska Jungfruöarna",
    "Virgin Islands (U.S.)" : "Amerikanska Jungfruöarna",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis- och Futunaöarna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sydafrika",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe"
},
"nplurals=2; plural=(n != 1);");
